netapp_ontap.models.oracle_on_san API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.oracle_on_san`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class OracleOnSanSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the OracleOnSan object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `archive_log: OracleOnNfsArchiveLog GET POST PATCH`

    The archive_log field of the oracle_on_san.

  `db: OracleOnNfsDb GET POST PATCH`

    The db field of the oracle_on_san.

  `igroup_name: str GET POST PATCH`

    The name of the initiator group through which the contents of this application will be accessed. Modification of this parameter is a disruptive operation. All LUNs in the application component will be unmapped from the current igroup and re-mapped to the new igroup.

  `new_igroups: List[OracleOnSanNewIgroups] POST PATCH`

    The list of initiator groups to create.

  `ora_home: OracleOnNfsOraHome GET POST PATCH`

    The ora_home field of the oracle_on_san.

  `os_type: str GET POST`

    The name of the host OS running the application.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - solaris
    - solaris_efi
    - vmware
    - windows
    - windows_2008
    - windows_gpt
    - xen
  `protection_type: MongoDbOnSanProtectionType GET POST PATCH`

    The protection_type field of the oracle_on_san.

  `redo_log: OracleOnNfsRedoLog GET POST PATCH`

    The redo_log field of the oracle_on_san.